@@ -32,7 +32,7 @@ pub use nettu_scheduler_domain::{
 };
 pub use schedule::{CreateScheduleInput, UpdateScheduleInput};
 pub use service::{
-    AddServiceUserInput, GetSerivceBookingSlotsInput, RemoveServiceUserInput,
+    AddServiceUserInput, GetServiceBookingSlotsInput, RemoveServiceUserInput,
     UpdateServiceUserInput,
 };
 pub use shared::{KVMetadata, MetadataFindInput};
@@ -45,10 +45,10 @@ pub use nettu_scheduler_api_structs::dtos::AccountWebhookSettingsDTO as AccountW
 pub use nettu_scheduler_api_structs::dtos::CalendarDTO as Calendar;
 pub use nettu_scheduler_api_structs::dtos::CalendarEventDTO as CalendarEvent;
 pub use nettu_scheduler_api_structs::dtos::CalendarSettingsDTO as CalendarSettings;
-pub use nettu_scheduler_api_structs::dtos::EventWithInstancesDTO as EventWithINstances;
+pub use nettu_scheduler_api_structs::dtos::EventWithInstancesDTO as EventWithIInstances;
 pub use nettu_scheduler_api_structs::dtos::ScheduleDTO as Schedule;
-pub use nettu_scheduler_api_structs::dtos::ServiceDTO as Service;
 pub use nettu_scheduler_api_structs::dtos::ServiceResourceDTO as ServiceResource;
+pub use nettu_scheduler_api_structs::dtos::ServiceWithUsersDTO as Service;
 pub use nettu_scheduler_api_structs::dtos::UserDTO as User;
 
 /// Nettu Scheduler Server SDK
